Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/nextcloudpi.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authornachoparker <nacho@ownyourbits.com>2018-04-05 19:49:05 +0300
committernachoparker <nacho@ownyourbits.com>2018-04-20 15:38:58 +0300
commita9458f526524fee8474f67b1999d49000a0e5fbf (patch)
tree39041c89a908306181bf70bb9a15c1d83a3a6608 /batch.sh
parent0d6c780911fd2e96681834764a057985d9bf2f81 (diff)
renamed to NextCloudPlusv0.53.29
Diffstat (limited to 'batch.sh')
-rwxr-xr-xbatch.sh10
1 files changed, 7 insertions, 3 deletions
diff --git a/batch.sh b/batch.sh
index f4c84649..f548237a 100755
--- a/batch.sh
+++ b/batch.sh
@@ -1,6 +1,6 @@
#!/bin/bash
# Batch creation of NextCloudPi images and containers
#
# Copyleft 2017 by Ignacio Nunez Hernanz <nacho _a_t_ ownyourbits _d_o_t_ com>
# GPL licensed (see end of file) * Use at your own risk!
@@ -19,11 +19,15 @@ IP=$1 # First argument is the QEMU Raspbian IP address
# docker x86
docker pull debian:stretch-slim
-make nextcloudpi-x86 && {
- docker push ownyourbits/nextcloudpi-x86
+make nextcloudplus-x86 && {
+ docker push ownyourbits/nextcloudplus-x86
docker push ownyourbits/nextcloud-x86
docker push ownyourbits/lamp-x86
docker push ownyourbits/debian-ncp-x86
+
+ # keep old container updated, at least for a while
+ docker tag ownyourbits/nextcloudplus-x86 ownyourbits/nextcloudpi-x86
+ docker push ownyourbits/nextcloudpi-x86
}
# docker armhf
@@ -1,6 +1,6 @@
#!/bin/bash
-# Batch creation of NextCloudPi images and containers
+# Batch creation of NextCloudPlus images and containers
#
# Copyleft 2017 by Ignacio Nunez Hernanz <nacho _a_t_ ownyourbits _d_o_t_ com>